info = {
    "name": "kde",
    "date_order": "DMY",
    "january": [
        "jan",
        "mwedi ntandi"
    ],
    "february": [
        "feb",
        "mwedi wa pili"
    ],
    "march": [
        "mac",
        "mwedi wa tatu"
    ],
    "april": [
        "apr",
        "mwedi wa nchechi"
    ],
    "may": [
        "mei",
        "mwedi wa nnyano"
    ],
    "june": [
        "jun",
        "mwedi wa nnyano na umo"
    ],
    "july": [
        "jul",
        "mwedi wa nnyano na mivili"
    ],
    "august": [
        "ago",
        "mwedi wa nnyano na mitatu"
    ],
    "september": [
        "mwedi wa nnyano na nchechi",
        "sep"
    ],
    "october": [
        "mwedi wa nnyano na nnyano",
        "okt"
    ],
    "november": [
        "mwedi wa nnyano na nnyano na u",
        "nov"
    ],
    "december": [
        "des",
        "mwedi wa nnyano na nnyano na m"
    ],
    "monday": [
        "liduva lyatatu",
        "ll3"
    ],
    "tuesday": [
        "liduva lyanchechi",
        "ll4"
    ],
    "wednesday": [
        "liduva lyannyano",
        "ll5"
    ],
    "thursday": [
        "liduva lyannyano na linji",
        "ll6"
    ],
    "friday": [
        "liduva lyannyano na mavili",
        "ll7"
    ],
    "saturday": [
        "liduva litandi",
        "ll1"
    ],
    "sunday": [
        "liduva lyapili",
        "ll2"
    ],
    "am": [
        "muhi"
    ],
    "pm": [
        "chilo"
    ],
    "year": [
        "mwaka"
    ],
    "month": [
        "mwedi"
    ],
    "week": [
        "lijuma"
    ],
    "day": [
        "lihiku"
    ],
    "hour": [
        "saa"
    ],
    "minute": [
        "dakika"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "0 day ago": [
            "nelo"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "lido"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "nundu"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
